==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/Units.h <==
// public final class soot.jimple.toolkits.callgraph.Units

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4e94d611bd10304a soot_jimple_toolkits_callgraph_Units

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_Units_H_
#define _JC_soot_jimple_toolkits_callgraph_Units_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_Units$sub_refs	_jc_soot_jimple_toolkits_callgraph_Units$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Units$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_Units$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Units$refs	_jc_soot_jimple_toolkits_callgraph_Units$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Units$nonrefs	_jc_soot_jimple_toolkits_callgraph_Units$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Units$object	_jc_soot_jimple_toolkits_callgraph_Units$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_Units$vmethods	_jc_soot_jimple_toolkits_callgraph_Units$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_Units$vtable	_jc_soot_jimple_toolkits_callgraph_Units$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_Units$vtype	_jc_soot_jimple_toolkits_callgraph_Units$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_Units$method$_init$fb346656e80483e8(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_callgraph_Units$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_callgraph_Units$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *);
extern void _jc_soot_jimple_toolkits_callgraph_Units$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Units$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Units$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Units$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_Units$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_Units$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_Units$vmethods	soot_jimple_toolkits_callgraph_Units;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_Units$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_Units$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_Units$sub_refs {
	struct _jc_object	*edges;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_Units$refs {
    _jc_soot_jimple_toolkits_callgraph_Units$sub_refs	soot_jimple_toolkits_callgraph_Units;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_Units$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_Units$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_Units$sub_nonrefs	soot_jimple_toolkits_callgraph_Units;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_Units$object {
	_jc_soot_jimple_toolkits_callgraph_Units$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_Units$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_Units$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_Units$vtype _jc_soot_jimple_toolkits_callgraph_Units$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_Units, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_Units$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_Units_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/Units.h <==
// public final class soot.jimple.toolkits.callgraph.Units

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4e94d611bd10304a soot_jimple_toolkits_callgraph_Units

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_Units_H_
#define _JC_soot_jimple_toolkits_callgraph_Units_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_Units$sub_refs	_jc_soot_jimple_toolkits_callgraph_Units$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Units$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_Units$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Units$refs	_jc_soot_jimple_toolkits_callgraph_Units$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Units$nonrefs	_jc_soot_jimple_toolkits_callgraph_Units$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_Units$object	_jc_soot_jimple_toolkits_callgraph_Units$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_Units$vmethods	_jc_soot_jimple_toolkits_callgraph_Units$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_Units$vtable	_jc_soot_jimple_toolkits_callgraph_Units$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_Units$vtype	_jc_soot_jimple_toolkits_callgraph_Units$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_Units$method$_init$fb346656e80483e8(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_callgraph_Units$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_callgraph_Units$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_callgraph_Units$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Units$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Units$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_Units$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_Units$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_Units$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_Units$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_Units$vmethods	soot_jimple_toolkits_callgraph_Units;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_Units$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_Units$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_Units$sub_refs {
	struct _jc_object	*edges;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_Units$refs {
    _jc_soot_jimple_toolkits_callgraph_Units$sub_refs	soot_jimple_toolkits_callgraph_Units;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_Units$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_Units$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_Units$sub_nonrefs	soot_jimple_toolkits_callgraph_Units;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_Units$object {
	_jc_soot_jimple_toolkits_callgraph_Units$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_Units$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_Units$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_Units$vtype _jc_soot_jimple_toolkits_callgraph_Units$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_Units, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_Units$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_Units_H_ */
